wipe

set openSeesType 1; # 1 - OpenSeesSP
	 	  ; # 2 - OpenSeesMP


switch $openSeesType {
   1 {
  	set numP 1
  	set pid 0

	set nx 2
	set ny 2
	set nz 2; # nz per processor
   }
   2 {
   	# some parameters
	set numP [getNP]
	set pid  [getPID]
	
	set nx 2
	set ny 2
	set nz 1; # nz per processor
   }
}

set d 1000.
set b 500.
set L 100.



set dx [expr $d/($nx*1.0)]
set dy [expr $b/($ny*1.0)]
set dz [expr $L/($numP * $nz)]

# create the modelbuilder
model Basic -ndm 3 -ndf 3

# add a material
set E 30000.
set v 0.2
nDMaterial ElasticIsotropic   1   $E $v

# add the nodes
set nodeList {}
set counter 1
for {set i 0} {$i<=[expr $numP*$nz]} {incr i 1} {
    for {set j 0} {$j<=$ny} {incr j 1} {
	for {set k 0} {$k<=$nx} {incr k 1} {
	    if {($i >= [expr $pid*$nz]) && ($i <= [expr ($pid+1)*$nz])} {
		node $counter [expr $k*$dx] [expr $j*$dy] [expr $i*$dz]
		puts "node $counter [expr $k*$dx] [expr $j*$dy] [expr $i*$dz] in $pid"
		
		lappend nodeList $counter
	    }
	    incr counter
	}
    }
}

set numNode [expr ($nx+1)*($ny+1)*($numP*$nz+1)]

# add the elements
set counter 1
for {set i 0} {$i<$numP*$nz} {incr i 1} {
         for {set j 0} {$j<$ny} {incr j 1} {
          set iNode [expr $i*($nx+1)*($ny+1) + 1 + $j*($nx+1)]
          set jNode [expr $iNode+1]
          set lNode [expr $iNode+($nx+1)]
          set kNode [expr $lNode+1]
           
          set mNode [expr ($i+1)*($nx+1)*($ny+1) + 1 + $j*($nx+1)]
          set nNode [expr $mNode+1]
          set pNode [expr $mNode+($nx+1)]
          set oNode [expr $pNode+1]
  
	for {set k 0} {$k<$nx} {incr k 1} {
	           if {$i >= [expr $pid*$nz] && $i < [expr ($pid+1)*$nz]} {
		      element stdBrick $counter $iNode $jNode $kNode $lNode $mNode $nNode $oNode $pNode 1
		      puts "element stdBrick $counter $iNode $jNode $kNode $lNode $mNode $nNode $oNode $pNode 1 in $pid"
	      }
	    incr counter
	    incr iNode 1
	    incr jNode 1
	    incr kNode 1
	    incr lNode 1
	    incr mNode 1
	    incr nNode 1
	    incr oNode 1
	    incr pNode 1
	}
    }
}

fixZ 0.0 1 1 1 

# create load pattern
#pattern DRMLoadPattern 1 -dt 0.02 -numSteps 3002 -stepsCached 25 -gridSize 4.0 4.0 2.0 -gridDataFace1 125 50  -gridDataFace2 125 50 -gridDataFace3 250 50 -gridDataFace4 250 50   -gridDataFace5 250 125 -filePathFace1 "/work/01312/kyungtae/DRMInput/LFface1R_aft7.txt"     -filePathFace2 "/work/01312/kyungtae/DRMInput/LFface2R_aft7.txt" -filePathFace3 "/work/01312/kyungtae/DRMInput/LFface3R_aft7.txt" -filePathFace4 "/work/01312/kyungtae/DRMInput/LFface4R_aft7.txt" -filePathFace5a "/work/01312/kyungtae/DRMInput/LFface51R_aft7.txt" -filePathFace5b "/work/01312/kyungtae/DRMInput/LFface52R_aft7.txt" -fileFace5aGridPoints 15000  -fileFace5bGridPoints 16626 -factor 0.01 -DRMBoxCrds 0.0 1000.0 0.0 500. 0.0 100.0                        
pattern DRMLoadPattern 1 -dt 0.02 -numSteps 3002 -stepsCached 25 -gridSize 4.0 4.0 2.0 -gridDataFace1 125 50  -gridDataFace2 125 50 -gridDataFace3 250 50 -gridDataFace4 250 50   -gridDataFace5 250 125 -filePathFace1 "/LFface1R_short.txt"     -filePathFace2 "/LFface2R_short.txt" -filePathFace3 "/LFface3R_short.txt" -filePathFace4 "/LFface4R_short.txt" -filePathFace5a "/LFface51R_short.txt" -filePathFace5b "/LFface52R_short.txt" -fileFace5aGridPoints 15000  -fileFace5bGridPoints 16626 -factor 0.01 -DRMBoxCrds 0.0 1000.0 0.0 500. 0.0 100.0                        

#if {$pid == [expr $numP-1]} {
#    timeSeries Linear 1
#    pattern Plain 1 1 {
#	load $numNode 10. 10. 0.
#    }
#}


switch $openSeesType {
   1 {
  	eval "recorder Node -file disp.out -time -node $nodeList -dof 1 2 3 disp"
   }
   2 {
   	eval "recorder Node -file disp.$pid.out -time -node $nodeList -dof 1 2 3 disp"
   }
}

integrator LoadControl 0.02
algorithm Linear
numberer Plain
constraints Plain
system ProfileSPD
analysis Static

analyze 1000

if {$pid == [expr $numP-1]} {	
    set disp [nodeDisp $numNode 1]
    puts "$disp"
}
#wipe
 
